@@ -98,7 +98,7 @@ void init(PyObject *module)
     ClassProperty::init(module);
     MetaFunction::init(module);
     // Init signal manager, so it will register some meta types used by QVariant.
-    SignalManager::instance();
+    SignalManager::init();
     initQApp();
 }
 
@@ -222,13 +222,13 @@ static QByteArrayList _SbkType_LookupProperty(PyTypeObject *type,
     if (origName.isEmpty())
         return QByteArrayList{};
     PyObject *mro = type->tp_mro;
-    auto n = PyTuple_GET_SIZE(mro);
+    auto n = PyTuple_Size(mro);
     auto len = std::strlen(origName);
     for (Py_ssize_t idx = 0; idx < n; idx++) {
-        PyTypeObject *base = reinterpret_cast<PyTypeObject *>(PyTuple_GET_ITEM(mro, idx));
+        auto *base = reinterpret_cast<PyTypeObject *>(PyTuple_GetItem(mro, idx));
         if (!SbkObjectType_Check(base))
             continue;
-        auto props = SbkObjectType_GetPropertyStrings(base);
+        auto *props = SbkObjectType_GetPropertyStrings(base);
         if (props == nullptr || *props == nullptr)
             continue;
         for (; *props != nullptr; ++props) {
@@ -262,11 +262,12 @@ static bool _setProperty(PyObject *qObj, PyObject *name, PyObject *value, bool *
     using Shiboken::AutoDecRef;
 
     QByteArray propName(Shiboken::String::toCString(name));
-    auto type = Py_TYPE(qObj);
+    auto *type = Py_TYPE(qObj);
     int flags = currentSelectId(type);
     int prop_flag = flags & 0x02;
     auto found = false;
-    QByteArray getterName{}, setterName{};
+    QByteArray getterName;
+    QByteArray setterName;
 
     auto fields = _SbkType_LookupProperty(type, propName, flags);
     if (!fields.isEmpty()) {
@@ -338,7 +339,7 @@ static std::optional<QMetaMethod> findSignal(const QMetaObject *mo,
         if (method.methodType() == QMetaMethod::Signal && method.name() == name)
             return method;
     }
-    auto *base = mo->superClass();
+    const auto *base = mo->superClass();
     return base != nullptr ? findSignal(base, name) : std::nullopt;
 }
 
@@ -346,7 +347,8 @@ bool fillQtProperties(PyObject *qObj, const QMetaObject *metaObj,
                       PyObject *kwds, bool allowErrors)
 {
 
-    PyObject *key, *value;
+    PyObject *key{};
+    PyObject *value{};
     Py_ssize_t pos = 0;
     int flags = currentSelectId(Py_TYPE(qObj));
     int snake_flag = flags & 0x01;
@@ -403,9 +405,9 @@ void runCleanupFunctions()
 
 static void destructionVisitor(SbkObject *pyObj, void *data)
 {
-    auto realData = reinterpret_cast<void **>(data);
-    auto pyQApp = reinterpret_cast<SbkObject *>(realData[0]);
-    auto pyQObjectType = reinterpret_cast<PyTypeObject *>(realData[1]);
+    auto *realData = reinterpret_cast<void **>(data);
+    auto *pyQApp = reinterpret_cast<SbkObject *>(realData[0]);
+    auto *pyQObjectType = reinterpret_cast<PyTypeObject *>(realData[1]);
 
     if (pyObj != pyQApp && PyObject_TypeCheck(pyObj, pyQObjectType)) {
         if (Shiboken::Object::hasOwnership(pyObj) && Shiboken::Object::isValid(pyObj, false)) {
@@ -424,7 +426,6 @@ void destroyQCoreApplication()
     QCoreApplication *app = QCoreApplication::instance();
     if (!app)
         return;
-    SignalManager::instance().clear();
 
     Shiboken::BindingManager &bm = Shiboken::BindingManager::instance();
     SbkObject *pyQApp = bm.retrieveWrapper(app);
@@ -453,7 +454,7 @@ std::size_t getSizeOfQObject(PyTypeObject *type)
 void initDynamicMetaObject(PyTypeObject *type, const QMetaObject *base, std::size_t cppObjSize)
 {
     //create DynamicMetaObject based on python type
-    auto userData = new TypeUserData(reinterpret_cast<PyTypeObject *>(type), base, cppObjSize);
+    auto *userData = new TypeUserData(reinterpret_cast<PyTypeObject *>(type), base, cppObjSize);
     userData->mo.update();
     Shiboken::ObjectType::setTypeUserData(type, userData, Shiboken::callCppDestructor<TypeUserData>);
 
@@ -476,7 +477,7 @@ TypeUserData *retrieveTypeUserData(PyTypeObject *pyTypeObj)
 
 TypeUserData *retrieveTypeUserData(PyObject *pyObj)
 {
-    auto pyTypeObj = PyType_Check(pyObj)
+    auto *pyTypeObj = PyType_Check(pyObj)
         ? reinterpret_cast<PyTypeObject *>(pyObj) : Py_TYPE(pyObj);
     return retrieveTypeUserData(pyTypeObj);
 }
@@ -489,7 +490,7 @@ const QMetaObject *retrieveMetaObject(PyTypeObject *pyTypeObj)
 
 const QMetaObject *retrieveMetaObject(PyObject *pyObj)
 {
-    auto pyTypeObj = PyType_Check(pyObj)
+    auto *pyTypeObj = PyType_Check(pyObj)
         ? reinterpret_cast<PyTypeObject *>(pyObj) : Py_TYPE(pyObj);
     return retrieveMetaObject(pyTypeObj);
 }
@@ -498,20 +499,19 @@ void initQObjectSubType(PyTypeObject *type, PyObject *args, PyObject * /* kwds *
 {
     PyTypeObject *qObjType = Shiboken::Conversions::getPythonTypeObject("QObject*");
 
-    PyObject *bases = PyTuple_GET_ITEM(args, 1);
-    int numBases = PyTuple_GET_SIZE(bases);
+    PyObject *bases = PyTuple_GetItem(args, 1);
 
     TypeUserData *userData = nullptr;
 
-    for (int i = 0; i < numBases; ++i) {
-        auto base = reinterpret_cast<PyTypeObject *>(PyTuple_GET_ITEM(bases, i));
+    for (Py_ssize_t i = 0, numBases = PyTuple_Size(bases); i < numBases; ++i) {
+        auto *base = reinterpret_cast<PyTypeObject *>(PyTuple_GetItem(bases, i));
         if (PyType_IsSubtype(base, qObjType)) {
             userData = retrieveTypeUserData(base);
             break;
         }
     }
     if (!userData) {
-        const char *className = Shiboken::String::toCString(PyTuple_GET_ITEM(args, 0));
+        const char *className = Shiboken::String::toCString(PyTuple_GetItem(args, 0));
         qWarning("Sub class of QObject not inheriting QObject!? Crash will happen when using %s.",
                  className);
         return;
@@ -594,7 +594,9 @@ PyObject *getHiddenDataFromQObject(QObject *cppSelf, PyObject *self, PyObject *n
 
     // Search on metaobject (avoid internal attributes started with '__')
     if (!attr) {
-        PyObject *type, *value, *traceback;
+        PyObject *type{};
+        PyObject *value{};
+        PyObject *traceback{};
         PyErr_Fetch(&type, &value, &traceback);     // This was omitted for a loong time.
 
         int flags = currentSelectId(Py_TYPE(self));
@@ -608,16 +610,14 @@ PyObject *getHiddenDataFromQObject(QObject *cppSelf, PyObject *self, PyObject *n
             // Note: before implementing this property handling, the meta function code
             // below created meta functions which was quite wrong.
             auto *subdict = _PepType_Lookup(Py_TYPE(self), PySideMagicName::property_methods());
-            PyObject *propName = PyDict_GetItem(subdict, name);
-            if (propName) {
+            if (PyObject *propName = PyDict_GetItem(subdict, name)) {
                 // We really have a property name and need to fetch the fget or fset function.
                 static PyObject *const _fget = Shiboken::String::createStaticString("fget");
                 static PyObject *const _fset = Shiboken::String::createStaticString("fset");
                 static PyObject *const _fdel = Shiboken::String::createStaticString("fdel");
                 static PyObject *const arr[3] = {_fget, _fset, _fdel};
-                auto prop = _PepType_Lookup(Py_TYPE(self), propName);
-                for (int idx = 0; idx < 3; ++idx) {
-                    auto *trial = arr[idx];
+                auto *prop = _PepType_Lookup(Py_TYPE(self), propName);
+                for (auto *trial : arr) {
                     auto *res = PyObject_GetAttr(prop, trial);
                     if (res) {
                         AutoDecRef elemName(PyObject_GetAttr(res, PySideMagicName::name()));
@@ -651,18 +651,15 @@ PyObject *getHiddenDataFromQObject(QObject *cppSelf, PyObject *self, PyObject *n
                 if (methMatch) {
                     if (method.methodType() == QMetaMethod::Signal) {
                         signalList.append(method);
-                    } else {
-                        PySideMetaFunction *func = MetaFunction::newObject(cppSelf, i);
-                        if (func) {
-                            PyObject *result = reinterpret_cast<PyObject *>(func);
-                            PyObject_SetAttr(self, name, result);
-                            return result;
-                        }
+                    } else if (auto *func = MetaFunction::newObject(cppSelf, i)) {
+                        auto *result = reinterpret_cast<PyObject *>(func);
+                        PyObject_SetAttr(self, name, result);
+                        return result;
                     }
                 }
             }
             if (!signalList.isEmpty()) {
-                PyObject *pySignal = reinterpret_cast<PyObject *>(
+                auto *pySignal = reinterpret_cast<PyObject *>(
                     Signal::newObjectFromMethod(self, signalList));
                 PyObject_SetAttr(self, name, pySignal);
                 return pySignal;
@@ -740,13 +737,13 @@ static inline bool isInternalObject(const char *name)
 
 static const QMetaObject *metaObjectCandidate(const QObject *o)
 {
-    auto *metaObject = o->metaObject();
+    const auto *metaObject = o->metaObject();
     // Skip QML helper types and Python objects
     if (hasDynamicMetaObject(o)) {
-        if (auto *super = metaObject->superClass())
+        if (const auto *super = metaObject->superClass())
             metaObject = super;
     }
-    for (auto *candidate = metaObject; candidate != nullptr; candidate = candidate->superClass()) {
+    for (const auto *candidate = metaObject; candidate != nullptr; candidate = candidate->superClass()) {
         if (!isInternalObject(candidate->className())) {
             metaObject = candidate;
             break;
@@ -762,7 +759,7 @@ static const char *typeName(const QObject *cppSelf)
 {
     const char *typeName = typeid(*cppSelf).name();
     if (!Shiboken::Conversions::getConverter(typeName)) {
-        auto *metaObject = metaObjectCandidate(cppSelf);
+        const auto *metaObject = metaObjectCandidate(cppSelf);
         for (; metaObject != nullptr; metaObject = metaObject->superClass()) {
             const char *name = metaObject->className();
             if (Shiboken::Conversions::getConverter(name)) {
@@ -790,7 +787,7 @@ PyTypeObject *getTypeForQObject(const QObject *cppSelf)
 
 PyObject *getWrapperForQObject(QObject *cppSelf, PyTypeObject *sbk_type)
 {
-    PyObject *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppSelf));
+    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppSelf));
     if (pyOut) {
         Py_INCREF(pyOut);
         return pyOut;
@@ -812,7 +809,7 @@ PyObject *getWrapperForQObject(QObject *cppSelf, PyTypeObject *sbk_type)
         }
     }
 
-    pyOut = Shiboken::Object::newObject(sbk_type, cppSelf, false, false, typeName(cppSelf));
+    pyOut = Shiboken::Object::newObjectWithHeuristics(sbk_type, cppSelf, false, typeName(cppSelf));
 
     return pyOut;
 }
@@ -844,17 +841,17 @@ PyObject *qStringToPyUnicode(QStringView s)
 QString pyStringToQString(PyObject *str)
 {
     if (str == Py_None)
-        return QString();
+        return {};
 
     if (PyUnicode_Check(str) != 0)
         return pyUnicodeToQString(str);
 
     if (PyBytes_Check(str)) {
-        const char *asciiBuffer = PyBytes_AS_STRING(str);
+        const char *asciiBuffer = PyBytes_AsString(str);
         if (asciiBuffer)
             return QString::fromLatin1(asciiBuffer);
     }
-    return QString();
+    return {};
 }
 
 // PySide-1499: Provide an efficient, correct PathLike interface
@@ -863,7 +860,7 @@ QString pyPathToQString(PyObject *path)
     // For empty constructors path can be nullptr
     // fallback to an empty QString in that case.
     if (!path)
-        return QString();
+        return {};
 
     // str or bytes pass through
     if (PyUnicode_Check(path) || PyBytes_Check(path))
@@ -872,7 +869,7 @@ QString pyPathToQString(PyObject *path)
     // Let PyOS_FSPath do its work and then fix the result for Windows.
     Shiboken::AutoDecRef strPath(PyOS_FSPath(path));
     if (strPath.isNull())
-        return QString();
+        return {};
     return QDir::fromNativeSeparators(pyStringToQString(strPath));
 }
 
@@ -1101,8 +1098,8 @@ static void formatPySequence(PyObject *obj, QDebug &debug)
 
 static void formatPyDict(PyObject *obj, QDebug &debug)
 {
-    PyObject *key;
-    PyObject *value;
+    PyObject *key{};
+    PyObject *value{};
     Py_ssize_t pos = 0;
     bool first = true;
     debug << '{';
@@ -1189,7 +1186,13 @@ static void formatPyObject(PyObject *obj, QDebug &debug)
         return;
     }
     if (PyType_Check(obj) == 0)
-        debug << pyTypeName(obj) << ": ";
+        debug << pyTypeName(obj);
+    const auto refs = Py_REFCNT(obj);
+    if (refs == UINT_MAX) // _Py_IMMORTAL_REFCNT
+        debug << ", immortal";
+    else
+        debug << ", refs=" << refs;
+    debug << ": ";
     formatPyObjectValue(obj, debug);
 }
 
